==> webkit-1.8.0.tar.xz: webkit-1.8.0/Source/WebCore/html/HTMLDivElement.h <==
/*
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef HTMLDivElement_h
#define HTMLDivElement_h

#include "HTMLElement.h"

namespace WebCore {

class HTMLDivElement : public HTMLElement {
public:
    static PassRefPtr<HTMLDivElement> create(Document*);
    static PassRefPtr<HTMLDivElement> create(const QualifiedName&, Document*);

protected:
    HTMLDivElement(const QualifiedName&, Document*);

private:
    virtual bool isPresentationAttribute(Attribute*) const OVERRIDE;
    virtual void collectStyleForAttribute(Attribute*, StylePropertySet*) OVERRIDE;
};

} // namespace WebCore

#endif // HTMLDivElement_h

==> webkit_1.9.2.orig.tar.xz: webkit-1.9.2/Source/WebCore/html/HTMLDivElement.h <==
/*
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef HTMLDivElement_h
#define HTMLDivElement_h

#include "HTMLElement.h"

namespace WebCore {

class HTMLDivElement : public HTMLElement {
public:
    static PassRefPtr<HTMLDivElement> create(Document*);
    static PassRefPtr<HTMLDivElement> create(const QualifiedName&, Document*);

protected:
    HTMLDivElement(const QualifiedName&, Document*);

private:
    virtual bool isPresentationAttribute(const QualifiedName&) const OVERRIDE;
    virtual void collectStyleForAttribute(Attribute*, StylePropertySet*) OVERRIDE;
};

} // namespace WebCore

#endif // HTMLDivElement_h
